==> kernlab_0.1-4.tar.gz: kernlab/src/bsvm.h <==
#ifndef _LIBSVM_H
#define _LIBSVM_H

#ifdef __cplusplus
extern "C" {
#endif
#include <R.h>
#include <Rinternals.h>

struct svm_node
{
	int index;
	double value;
};

struct svm_problem
{
	int l, n;
	double *y;
	struct svm_node **x;
};

enum { C_SVC, KBB, SPOC, EPSILON_SVR };	/* svm_type */
enum { LINEAR, POLY, RBF, SIGMOID, R };	/* kernel_type */

struct svm_parameter
{
	int svm_type;
	int kernel_type;
	double degree;	/* for poly */
	double gamma;	/* for poly/rbf/sigmoid */
	double coef0;	/* for poly/sigmoid */

	/* these are for training only */
	double cache_size; /* in MB */
	double eps;	/* stopping criteria */
	double C; /* for C_SVC, KBB, EPSILON_SVR and EPSILON_SVR */
	int nr_weight;		/* for C_SVC, KBB and SPOC */
	int *weight_label;	/* for C_SVC, KBB and SPOC */
	double* weight;		/* for C_SVC, KBB and SPOC */
	double p;	/* for EPSILON_SVR */
	int shrinking;	/* use the shrinking heuristics */
	int qpsize;	/* for C_SVC, KBB and EPSILON_SVR */
	double Cbegin, Cstep;	/* for linear kernel */ 
	SEXP rho;
	SEXP expr;
};

struct BQP
{
	double eps;
        int n;
        double *x, *C, *Q, *p;
};

struct svm_model *svm_train(const struct svm_problem *prob,
			    const struct svm_parameter *param);

int svm_save_model(const char *model_file_name, const struct svm_model *model);

struct svm_model *svm_load_model(const char *model_file_name);

double svm_predict(const struct svm_model *model, const struct svm_node *x);

void svm_destroy_model(struct svm_model *model);

const char *svm_check_parameter(const struct svm_problem *prob, const struct svm_parameter *param);

#ifdef __cplusplus
}
#endif

#endif /* _LIBSVM_H */

==> kernlab_0.2-2.tar.gz: kernlab/src/bsvm.h <==
#ifndef _LIBSVM_H
#define _LIBSVM_H

#ifdef __cplusplus
extern "C" {
#endif
#include <R.h>
#include <Rinternals.h>

struct svm_node
{
	int index;
	double value;
};

struct svm_problem
{
	int l, n;
	double *y;
	struct svm_node **x;
};

enum { C_SVC, KBB, SPOC, EPSILON_SVR };	/* svm_type */
enum { LINEAR, POLY, RBF, SIGMOID, R, LAPLACE, BESSEL, ANOVA};	/* kernel_type */

struct svm_parameter
{
	int svm_type;
	int kernel_type;
	double degree;	/* for poly */
	double gamma;	/* for poly/rbf/sigmoid */
	double coef0;	/* for poly/sigmoid */
        double lim; /* for bessel */ 
	/* these are for training only */
	double cache_size; /* in MB */
	double eps;	/* stopping criteria */
	double C; /* for C_SVC, KBB, EPSILON_SVR and EPSILON_SVR */
	int nr_weight;		/* for C_SVC, KBB and SPOC */
	int *weight_label;	/* for C_SVC, KBB and SPOC */
	double* weight;		/* for C_SVC, KBB and SPOC */
	double p;	/* for EPSILON_SVR */
	int shrinking;	/* use the shrinking heuristics */
	int qpsize;	/* for C_SVC, KBB and EPSILON_SVR */
	double Cbegin, Cstep;	/* for linear kernel */ 
	SEXP rho;
	SEXP expr;
        int d;
};

struct BQP
{
	double eps;
        int n;
        double *x, *C, *Q, *p;
};

struct svm_model *svm_train(const struct svm_problem *prob,
			    const struct svm_parameter *param);

int svm_save_model(const char *model_file_name, const struct svm_model *model);

struct svm_model *svm_load_model(const char *model_file_name);

double svm_predict(const struct svm_model *model, const struct svm_node *x);

void svm_destroy_model(struct svm_model *model);

const char *svm_check_parameter(const struct svm_problem *prob, const struct svm_parameter *param);

#ifdef __cplusplus
}
#endif

#endif /* _LIBSVM_H */
